@@ -4,46 +4,22 @@ Class::MakeMethods::Composite::Universal - Composite Method Tricks
 
 =head1 SYNOPSIS
 
-  package MyClass;
-  use Class::MakeMethods::Composite::Universal (
-    hook => 'init',
+  Class::MakeMethods::Composite::Universal->make_patch(
+    -TargetClass => 'SomeClass::OverYonder',
+    name => 'foo',
+    pre_rules => [ 
+      sub { 
+	my $method = pop; 
+	warn "Arguments for foo:", @_ 
+      } 
+    ]
+    post_rules => [ 
+      sub { 
+	warn "Result of foo:", Class::MakeMethods::Composite->CurrentResults 
+      } 
+    ]
   );
 
-  sub new {
-    my $package = shift;
-    my $self = bless {}, $package;
-    $self->init();
-    return $self;
-  }
-
-  MyClass->
-  
-  package MySubClass;
-  @ISA = 'MyClass';
-  ...
-  
-  MyClass->foo( 'Foozle' );
-  print MyClass->foo();
-  
-  MyClass->my_list(0 => 'Foozle', 1 => 'Bang!');
-  print MyClass->my_list(1);
-  
-  MyClass->my_index('broccoli' => 'Blah!', 'foo' => 'Fiddle');
-  print MyClass->my_index('foo');
-  ...
-  
-  my $obj = MyClass->new(...);
-  print $obj->foo();     # all instances default to same value
-  
-  $obj->foo( 'Foible' ); # until you set a value for an instance
-  print $obj->foo();     # it now has its own value
-  
-  print MySubClass->foo();    # intially same as superclass
-  MySubClass->foo('Foobar');  # but overridable per subclass
-  print $subclass_obj->foo(); # and shared by its instances
-  $subclass_obj->foo('Fosil');# until you override them... 
-
-
 =head1 DESCRIPTION
 
 The Composite::Universal suclass of MakeMethods provides some generally-applicable types of methods based on Class::MakeMethods::Composite.
@@ -64,7 +40,7 @@ use Carp;
 
 The patch ruleset generates composites whose core behavior is based on an existing subroutine.
 
-Here's an sample usage:
+Here's a sample usage:
 
   sub foo {
     my $count = shift;
@@ -138,13 +114,18 @@ Provides the '-ForceInstall' flag, which is required to ensure that the patched
 For example, one could add logging to an existing method as follows:
 
   Class::MakeMethods::Composite::Universal->make_patch(
-    -TargetClass => 'SomeClassOverYonder',
+    -TargetClass => 'SomeClass::OverYonder',
     name => 'foo',
     pre_rules => [ 
-      sub { my $method = pop; warn "Arguments:", @_ } 
+      sub { 
+	my $method = pop; 
+	warn "Arguments for foo:", @_ 
+      } 
     ]
     post_rules => [ 
-      sub { my $method = pop; warn "Result:", $method->{result} } 
+      sub { 
+	warn "Result of foo:", Class::MakeMethods::Composite->CurrentResults 
+      } 
     ]
   );
 
@@ -155,54 +136,6 @@ sub make_patch {
 }
 
 
-########################################################################
-
-=head2 hook
-
-External interface is normal; internally calls array of fragments. 
-Among other things, this should allow meta-methods to individually
-provide "on init" or "on destroy" code.
-
-How do you add to the hook? Pre/post, or arbitrary order?
-Ability to remove/replace specifc ones? Assign name? Loop in name order?
-
-  package MyWidget;
-  use C::MM::Composite (
-    hook => 'init',
-  );
-  
-  sub new {
-    my $widget = ...;
-    $widget->init();
-    return $widget;
-  }
-  
-  MyWidget->_hook_method('init', 
-    'post+' => sub { (shift)->{count} ||= 3 },
-  );
-
-B<NOTE: THIS METHOD GENERATOR IS INCOMPLETE.> 
-
-The _hook_method interface, or an improvement thereto, needs to be added.
-
-Hook methods should call up the inheritance tree. 
-
-=cut
-
-use vars qw( %HookFragments );
-
-sub hook {
-  (shift)->_build_composite( \%HookFragments, @_ );
-}
-
-%HookFragments = (
-  '' => [
-    'do' => sub {
-	1
-      },
-  ],
-);
-
 ########################################################################
 
 =head1 SEE ALSO
@@ -210,10 +143,6 @@ sub hook {
 See L<Class::MakeMethods> and L<Class::MakeMethods::Composite> for
 an overview of the method-generation framework this is based on.
 
-See L<Class::MakeMethods::Guide> for a getting-started guide,
-annotated examples of usage, and a listing of the method generation
-classes included in this distribution.
-
 See L<Class::MakeMethods::ReadMe> for distribution, installation,
 version and support information.
 
